@@ -128,7 +128,7 @@ def get_template_LEDET_inputs_sheet():
         ['sim3D_min_ds_fine', None, 'Minimum spatial mesh size, in the fine-mesh part [m]'],
         ['sim3D_min_nodesPerStraightPart', None, 'Minimum number of nodes in each straight-section part [-]'],
         ['sim3D_min_nodesPerEndsPart', None, 'Minimum number of nodes in each end-section part [-]'],
-        ['sim3D_idxFinerMeshHalfTurn', None, 'Indices of the half-turns with finer mesh [-]'],
+        ['sim3D_idxFinerMeshHalfTurn', None, 'Indices of the half-turns with finer mesh (in LEDET half-turn order, NOT in electrical order) [-]'],
         ['sim3D_Tpulse_sPosition', None, 'Center of the temperature gaussian distribution, i.e. position where the quench starts [m]'],
         ['sim3D_Tpulse_peakT', None, 'Peak temperature of the gaussian distribution [K]'],
         ['sim3D_Tpulse_width', None, 'Width of the temperature gaussian distribution, i.e. 2*sigma [m]'],
