@@ -516,30 +516,33 @@ class ParserRoxie:
                     block_nr = int(rowSplitStr[0])
                     blocks_list = []
 
-                    for group in data.groups:
-                        blocks_list += data.groups[group].blocks
-                        if block_nr in data.groups[group].blocks:
-                            group_nr = int(group)
-                            symm = data.groups[group].symm
+                    if not data.groups:
+                        coil = 1
+                    else:
+                        for group in data.groups:
+                            blocks_list += data.groups[group].blocks
+                            if block_nr in data.groups[group].blocks:
+                                group_nr = int(group)
+                                symm = data.groups[group].symm
 
-                            if not data.transs or self.shift_flag <= 1:
-                                coil = 1
-                            else:
-                                groups_list = []
-                                trans_blocks_list = []
-                                for trans in data.transs:
-                                    if data.transs[trans].act == 1:
-                                        groups_list += data.transs[trans].bcs
-                                        if int(group) in data.transs[trans].bcs and data.transs[trans].string == \
-                                                'SHIFT2':
-                                            coil = int(trans)
-                                    elif data.transs[trans].act == 3:
-                                        trans_blocks_list += data.transs[trans].bcs
-                                        if data.transs[trans].string == 'SHIFT2':
-                                            coil = int(trans)
-                                    else:
-                                        raise Exception('Type of transformation not supported: check "ACT" under '
-                                                        '"EULER" in the .data file.')
+                                if not data.transs or self.shift_flag <= 1:
+                                    coil = 1
+                                else:
+                                    groups_list = []
+                                    trans_blocks_list = []
+                                    for trans in data.transs:
+                                        if data.transs[trans].act == 1:
+                                            groups_list += data.transs[trans].bcs
+                                            if int(group) in data.transs[trans].bcs and data.transs[trans].string == \
+                                                    'SHIFT2':
+                                                coil = int(trans)
+                                        elif data.transs[trans].act == 3:
+                                            trans_blocks_list += data.transs[trans].bcs
+                                            if data.transs[trans].string == 'SHIFT2':
+                                                coil = int(trans)
+                                        else:
+                                            raise Exception('Type of transformation not supported: check "ACT" under '
+                                                            '"EULER" in the .data file.')
                     if 'coil' not in locals():
                         if block_nr not in blocks_list:
                             raise Exception('The current block does not belong to any group: check "LAYER" in the '
@@ -557,10 +560,10 @@ class ParserRoxie:
                         layer = self.layer_radius.index(radius) + 1
 
                     turn = float(rowSplitStr[11])
-                    if turn == 0:
-                        pole = 1
+                    if 'symm' in locals():
+                        pole = floor(turn * symm / 360 + 1)
                     else:
-                        pole = turn * symm / 360 + 1
+                        pole = block_nr
 
                     data.blocks[rowSplitStr[0]] = pd.Block(type=int(rowSplitStr[1]), nco=int(rowSplitStr[2]),
                                                            radius=radius, phi=float(rowSplitStr[4]),
@@ -1248,11 +1251,6 @@ class ParserRoxie:
             # else:
             #     pass
 
-            # ax.add_patch(patches.Circle((coil.bore_center.x, coil.bore_center.y), radius=radius, color='b'))
-            # self.ax.add_line(lines.Line2D([xCable[0], xCable[3]], [yCable[0], yCable[3]], color='red'))
-            # self.ax.add_line(lines.Line2D([xCable[3], xCable[2]], [yCable[3], yCable[2]], color='red'))
-            # self.ax.add_line(lines.Line2D([xCable[2], xCable[1]], [yCable[2], yCable[1]], color='red'))
-            # self.ax.add_line(lines.Line2D([xCable[1], xCable[0]], [yCable[1], yCable[0]], color='red'))
             if c == self.block.nco - 1 and c == 0:
                 corner0 = [xCable[0], yCable[0]]  # 1
                 corner3 = [xCable[3], yCable[3]]  # 4
@@ -1271,11 +1269,6 @@ class ParserRoxie:
                 #                      '2': pd.Coord(x=x[0][1], y=y[0][1]),
                 #                      '3': pd.Coord(x=x[0][2], y=y[0][2]),
                 #                      '4': pd.Coord(x=x[-1][3], y=y[-1][3])})
-            # xBare.append(xBareCable)
-            # yBare.append(yBareCable)
-            # x.append(xCable)
-            # y.append(yCable)
-            # # I.append(current)
 
             # Find strand positions
             alphaS = math.atan2(yBareCable[2] - yBareCable[1], xBareCable[2] - xBareCable[1])
@@ -1308,34 +1301,46 @@ class ParserRoxie:
         # Compute two new corners to make concentric blocks by intersecting a circle (having a radius equal to the
         # distance between the bore center and the starting inner/outer block corner) with the straight line
         # passing through the ending block corners that need to be replaced
-        new_corners_inner = geometricFunctions.intersectLineCircle(
-            geometricFunctions.findLineThroughTwoPoints(corner0, corner3),
-            [radius, coil.bore_center.x, coil.bore_center.y])
-        if min(abs(new_corners_inner[0][0] - corner0[0]),
-               abs(new_corners_inner[1][0] - corner0[0])) == abs(new_corners_inner[0][0] - corner0[0]):
-            new_inner = new_corners_inner[0]
-        else:
-            new_inner = new_corners_inner[1]
-        outer_radius = (np.sqrt(np.square(corner2[0] - coil.bore_center.x) +
-                                np.square(corner2[1] - coil.bore_center.y)))
-        new_corners_outer = geometricFunctions.intersectLineCircle(
-            geometricFunctions.findLineThroughTwoPoints(corner0, corner3),
-            [outer_radius, coil.bore_center.x, coil.bore_center.y])
-        if min(abs(new_corners_outer[0][0] - corner0[0]),
-               abs(new_corners_outer[1][0] - corner0[0])) == abs(new_corners_outer[0][0] - corner0[0]):
-            new_outer = new_corners_outer[0]
-        else:
-            new_outer = new_corners_outer[1]
-        if corner0[0] < corner1[0]:
-            block.block_corners.iL = pd.Coord(x=sigDig(new_inner[0]), y=sigDig(new_inner[1]))  # 1
-            block.block_corners.oL = pd.Coord(x=sigDig(new_outer[0]), y=sigDig(new_outer[1]))  # 4
+        # self.ax.add_patch(patches.Circle((coil.bore_center.x, coil.bore_center.y), radius=radius, color='b'))
+        # self.ax.add_line(lines.Line2D([corner0[0], corner3[0]], [corner0[1], corner3[1]], color='red'))
+        # self.ax.add_line(lines.Line2D([corner3[0], corner2[0]], [corner3[1], corner2[1]], color='red'))
+        # self.ax.add_line(lines.Line2D([corner2[0], corner1[0]], [corner2[1], corner1[1]], color='red'))
+        # self.ax.add_line(lines.Line2D([corner1[0], corner0[0]], [corner1[1], corner0[1]], color='red'))
+        # plt.show()
+        if self.block.type == 2:
+            block.block_corners.iL = pd.Coord(x=sigDig(corner0[0]), y=sigDig(corner0[1]))  # 1
+            block.block_corners.oL = pd.Coord(x=sigDig(corner3[0]), y=sigDig(corner3[1]))  # 4
             block.block_corners.iR = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))  # 2
             block.block_corners.oR = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))  # 3
         else:
-            block.block_corners.iR = pd.Coord(x=sigDig(new_inner[0]), y=sigDig(new_inner[1]))
-            block.block_corners.oR = pd.Coord(x=sigDig(new_outer[0]), y=sigDig(new_outer[1]))
-            block.block_corners.iL = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))
-            block.block_corners.oL = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))
+            new_corners_inner = geometricFunctions.intersectLineCircle(
+                geometricFunctions.findLineThroughTwoPoints(corner0, corner3),
+                [radius, coil.bore_center.x, coil.bore_center.y])
+            if min(abs(new_corners_inner[0][0] - corner0[0]),
+                   abs(new_corners_inner[1][0] - corner0[0])) == abs(new_corners_inner[0][0] - corner0[0]):
+                new_inner = new_corners_inner[0]
+            else:
+                new_inner = new_corners_inner[1]
+            outer_radius = (np.sqrt(np.square(corner2[0] - coil.bore_center.x) +
+                                    np.square(corner2[1] - coil.bore_center.y)))
+            new_corners_outer = geometricFunctions.intersectLineCircle(
+                geometricFunctions.findLineThroughTwoPoints(corner0, corner3),
+                [outer_radius, coil.bore_center.x, coil.bore_center.y])
+            if min(abs(new_corners_outer[0][0] - corner0[0]),
+                   abs(new_corners_outer[1][0] - corner0[0])) == abs(new_corners_outer[0][0] - corner0[0]):
+                new_outer = new_corners_outer[0]
+            else:
+                new_outer = new_corners_outer[1]
+            if corner0[0] < corner1[0]:
+                block.block_corners.iL = pd.Coord(x=sigDig(new_inner[0]), y=sigDig(new_inner[1]))  # 1
+                block.block_corners.oL = pd.Coord(x=sigDig(new_outer[0]), y=sigDig(new_outer[1]))  # 4
+                block.block_corners.iR = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))  # 2
+                block.block_corners.oR = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))  # 3
+            else:
+                block.block_corners.iR = pd.Coord(x=sigDig(new_inner[0]), y=sigDig(new_inner[1]))
+                block.block_corners.oR = pd.Coord(x=sigDig(new_outer[0]), y=sigDig(new_outer[1]))
+                block.block_corners.iL = pd.Coord(x=sigDig(corner1[0]), y=sigDig(corner1[1]))
+                block.block_corners.oL = pd.Coord(x=sigDig(corner2[0]), y=sigDig(corner2[1]))
 
         # ((block.pole % 2 == 0) * np.sign(-I[0]) +
         #  (block.pole % 2 != 0) * np.sign(I[0])) * block.radius / 1e3]
@@ -1381,7 +1386,7 @@ class ParserRoxie:
 
         # if verbose:
         #     print('Total number of conductors (half-turns): {}'.format(len(self.xPos)))
-        # plt.show()
+        #plt.show()
         return self.data.coil
 
     def getWedgePositions(self, coil: pd.CoilData = None, verbose: bool = False):
